from .utils import draw_title, BASE_DIR
from PIL import Image
import argparse
import os
import sys


if __name__ == "__main__":

    parser = argparse.ArgumentParser(description='Qlik Tools')
    parser.add_argument('--project', type=str, required=True)
    parser.add_argument('--layer', type=str, required=True, choices=['Extração', 'Transformação', 'Visualização'])
    parser.add_argument('--version', type=str, required=True)
    parser.add_argument('--output_dir', type=str, required=True)

    args = parser.parse_args()

    background_img = Image.open(f'{BASE_DIR}/assets/images/background.png')

    final_img = draw_title(background_img, args.project, f'{args.layer} - {args.version}')

    filepath = f'{args.output_dir}/{args.project}_{args.layer}_thumbnail_{args.version}.png'
    final_img.save(filepath)

    if sys.platform == 'win32':
        os.system(filepath)
    else:
        sys.stdout.write(f'The file was created in the following path: {filepath}.\n')


from PIL import ImageDraw, ImageFont
import os

BASE_DIR = os.path.dirname(os.path.abspath(__file__))

def get_text_dimensions(text_string, font):
    # https://stackoverflow.com/a/46220683/9263761
    ascent, descent = font.getmetrics()

    text_width = font.getmask(text_string).getbbox()[2]
    text_height = font.getmask(text_string).getbbox()[3] + descent

    return (text_width, text_height)

def draw_title(img, title, subtitle, color=(255, 255, 255)):
    img_width, img_height = img.size
    draw = ImageDraw.Draw(img)

    title_font = ImageFont.truetype(f'{BASE_DIR}/assets/fonts/Arial Black.ttf', 400)
    subtitle_font = ImageFont.truetype(f'{BASE_DIR}/assets/fonts/Arial.ttf', int(400 * 0.30))

    title_width, title_height = get_text_dimensions(title, title_font)
    subtitle_width, subtitle_height = get_text_dimensions(subtitle, subtitle_font)

    title_position = ((img_width-title_width)/2, 100)
    subtitle_position = ((img_width - subtitle_width) / 2, 600)

    draw.text(title_position, title, color, font=title_font)
    draw.text(subtitle_position, subtitle, color, font=subtitle_font)

    return img



import setuptools

REQUIRED_PACKAGES = ['Pillow']

setuptools.setup(
    name="qlikutils",
    version="1.1.1",
    author="Kin Torres",
    author_email="kin.mello@gmail.com",
    description="Toolkit to use with Qlik",
    packages=setuptools.find_namespace_packages(),
    package_data={
        "qlikutils.assets": ["*"],
        "qlikutils.assets.images": ["*.png"],
        "qlikutils.assets.fonts": ["*.ttf"]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=REQUIRED_PACKAGES
)
